import os

from django.conf import settings

from openid_connect import connect, connect_url

AUTH_URL = os.environ.get("AUTH_URL")
if AUTH_URL:
	server = connect_url(AUTH_URL)
else:
	server = connect(settings.AUTH_SERVER, settings.AUTH_CLIENT_ID, settings.AUTH_CLIENT_SECRET, getattr(settings, 'AUTH_PROTOCOL', None))



from django.conf import settings
from django.contrib import auth
from django.shortcuts import redirect, resolve_url
from django.urls import reverse
from django.utils.http import is_safe_url

from . import auth as _auth

def login(request):
	return_path = request.GET.get(auth.REDIRECT_FIELD_NAME, "")

	return redirect(_auth.server.authorize(
		redirect_uri = request.build_absolute_uri(reverse("django_auth_oidc:callback")),
		state = return_path,
	))

def callback(request):
	return_path = request.GET.get("state")

	res = _auth.server.request_token(
		redirect_uri = request.build_absolute_uri(reverse("django_auth_oidc:callback")),
		code = request.GET["code"],
	)

	User = auth.get_user_model()
	user, created = User.objects.get_or_create(username=res.id["sub"])
	auth.login(request, user)

	url_is_safe = is_safe_url(
		url = return_path,
		host = request.get_host(),
		#allowed_hosts = set(request.get_host()),
		#require_https = request.is_secure(),
	)
	if not url_is_safe:
		return redirect(resolve_url(settings.LOGIN_REDIRECT_URL))
	return redirect(return_path)



#!/usr/bin/env python3

from setuptools import setup

with open('README.rst') as f:
	readme = f.read()

setup(
	name = "django-auth-oidc",
	version = "0.2.0",
	description = "OpenID Connect authentication support for Django",
	long_description = readme,
	author = "Aiakos Contributors",
	author_email = "aiakos@aiakosauth.com",
	url = "https://gitlab.com/aiakos/django-auth-oidc",
	keywords = "django auth oauth openid oidc social ldap",

	install_requires = ["django>=1.10.0", "openid_connect"],

	packages = ["django_auth_oidc"],
	zip_safe = True,

	license = "MIT",
	classifiers = [
		'Development Status :: 4 - Beta',
		'Intended Audience :: System Administrators',
		'License :: OSI Approved :: MIT License',
		'License :: OSI Approved :: BSD License',
		'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.5',
		'Programming Language :: Python :: 3.6',
		'Topic :: System :: Systems Administration :: Authentication/Directory',
	]
)
